# MetaX

**MetaX** is a novel tool for linking peptide sequences with taxonomic and functional information in **Metaproteomics**. We introduce the ***Operational Taxon-Function (OTF)*** concept to explore microbial roles and interactions ("**who is doing what and how**") within ecosystems. 

MetaX also features <u>statistical modules</u> and <u>plotting tools</u> for analyzing peptides, taxa, functions, proteins, and taxon-function contributions across groups.


![abstract](https://github.com/byemaxx/MetaX/raw/main/Docs/MetaX_Cookbook.assets/abstract.png)

## Operational Taxon-Function (OTF)

**Operational Taxon-Function (OTF) Unit**: An operational unit which represents the association between specific taxa and biological functions. 

![OTF_Structure](https://github.com/byemaxx/MetaX/raw/main/Docs/MetaX_Cookbook.assets/OTF_Structure.png)

## OTF Analyzer

The Tools in OTF Analyzer

![compostion](https://github.com/byemaxx/MetaX/raw/main/Docs/MetaX_Cookbook.assets/composition.png)

## OTF Examples

Linking Taxa and Functions in different levels of the hierarchy, and various functional categories. e.g., **Species-KO**, **Genus-CAZy**, **Phylum-EC**, etc. Lots of visualization tools can be selected.

**Network**

**Dots** represent <u>taxa</u> and **squares** represent <u>functions</u> in the network.

- <img src="https://github.com/byemaxx/MetaX/raw/main/Docs/MetaX_Cookbook.assets/tf_link_net.png" alt="OTF" style="zoom: 50%;" />



**Heatmap**

Show all Taxa of a function.

- <img src="https://github.com/byemaxx/MetaX/raw/main/Docs/MetaX_Cookbook.assets/taxa_func_link_heatmap.png" alt="tf_link_heatmap" style="zoom:50%;" />

**Bar**

Show all functions of a taxon

- <img src="https://github.com/byemaxx/MetaX/raw/main/Docs/MetaX_Cookbook.assets/taxa_func_link_bar.png" alt="tf_link_bar" style="zoom:50%;" />

**OTF Heatmap**

Show OTFS intensity in groups(samples), e.g., **Species-KO** OTF Heatmap

<img src="https://github.com/byemaxx/MetaX/raw/main/Docs/MetaX_Cookbook.assets/otf_heatmap.png" alt="otf_heatmap" style="zoom:50%;" />

## Download & Installation
- **Desktop Version** (Recommended)

  > The desktop version comes fully set up and ready to use, including all required dependencies and a graphical user interface.
  >
  > <a href="https://shiny2.imetalab.ca/shiny/rstudio/metax_download/" target="_blank">Download the MetaX Desktop Version</a>

<br>

- **Command-line version**

    > Use [PyPi](https://pypi.org/project/MetaXTools/) to install, then type `metax` in the terminal to launch the GUI.
    >
    > `python -m pip install MetaXTools`



## Guidebook

- `Desktop Version(desktop)`:
  - Refer to the <a href="https://byemaxx.github.io/MetaX/" target="_blank">MetaX Cookbook</a> for detailed instructions on how to use MetaX with the graphical user interface.
  <br>
- `Command-line version`:
  - Read the example documentation in the [Notebook](https://github.com/byemaxx/MetaX/blob/main/Docs/example.ipynb) for detailed instructions and examples.


## Citing
If you use MetaX in your research, please cite the following publication:

> **MetaX: A peptide centric metaproteomic data analysis platform using Operational Taxa-Functions (OTF)**. *Wu, Q., Ning, Z., Zhang, A., Zhang, X., Sun, Z., & Figeys, D.* (2024).  bioRxiv. DOI:  <a href="https://doi.org/10.1101/2024.04.19.590315" target="_blank">10.1101/2024.04.19.590315</a>.

